@@ -112,7 +112,6 @@ class Client(metaclass=_Singleton):
     """
 
     _local_node_manager: LocalNodeManager
-
     _asyncio_lock = asyncio.Lock()
     _config: LibConfigModel
     __cogs_registered = set()
@@ -321,9 +320,7 @@ class Client(metaclass=_Singleton):
                             client_id = spotify.get("client_id")
                             client_secret = spotify.get("client_secret")
                             if client_id and client_secret:
-                                LOGGER.debug(
-                                    "Existing Spotify tokens found; Using them - %s - %s", client_id, client_secret
-                                )
+                                LOGGER.debug("Existing Spotify tokens found; Using clientID - %s", client_id)
                         else:
                             LOGGER.info("PyLav being run from a non Red bot")
                             client_id = None
@@ -756,7 +753,8 @@ class Client(metaclass=_Singleton):
                         await self._local_node_manager.shutdown()
                         await self._session.close()
                         await self._cached_session.close()
-                        self._scheduler.shutdown(wait=True)
+                        if self._scheduler:
+                            self._scheduler.shutdown(wait=True)
                     except Exception as e:
                         LOGGER.critical("Failed to shutdown the client", exc_info=e)
                     if self.__old_process_command_method is not None:
@@ -1055,7 +1053,7 @@ class Client(metaclass=_Singleton):
                     queries_failed.append(query)
             else:
                 queries_failed.append(query)
-                LOGGER.warning("Unhandled query: %s, %s", query.__dict__, query.query_identifier)
+                LOGGER.warning("Unhandled query: %s, %s", query.to_dict(), query.query_identifier)
         return successful_tracks, track_count, queries_failed
 
     @staticmethod
